==> myfaces-tobago-3.1.1-dist.zip: org/apache/myfaces/tobago/sanitizer/IgnoringSanitizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.sanitizer;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Properties;

/**
 * The IgnoringSanitizer doesn't protect you against malicious code. Use it with care, or better not use it.
 */
public class IgnoringSanitizer implements Sanitizer {

  private static final Logger LOG = LoggerFactory.getLogger(IgnoringSanitizer.class);

  @Override
  public String sanitize(String html) {
    return html;
  }

  @Override
  public void setProperties(Properties configuration) {
    LOG.warn("No configuration needed! Got: '{}'", configuration);
  }

  @Override
  public String toString() {
    return getClass().getSimpleName();
  }
}

==> myfaces-tobago-4.6.0-dist.zip: org/apache/myfaces/tobago/sanitizer/IgnoringSanitizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.sanitizer;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Properties;

/**
 * The IgnoringSanitizer doesn't protect you against malicious code. Use it with care, or better not use it.
 */
public class IgnoringSanitizer implements Sanitizer {

  private static final Logger LOG = LoggerFactory.getLogger(IgnoringSanitizer.class);

  @Override
  public String sanitize(final String html) {
    return html;
  }

  @Override
  public void setProperties(final Properties configuration) {
    LOG.warn("No configuration needed! Got: '{}'", configuration);
  }

  @Override
  public String toString() {
    return getClass().getSimpleName();
  }
}
